==============
Listing Search
==============


Working With Listing Searches
=============================


Activate a Listing Search
-------------------------

To show a listing search within your site, go to the place in your Plone site where you want to have the listing search available and open the **Actions**-menu.
Select **Activate Listing Search** from the available options:

.. figure:: ../../_images/listing_search_activate.png

   Activate a listing search

When the **Listing Search** was activated, you will see a status message:

.. figure:: ../../_images/listing_search_activate_done.png

   Confirmation that the listing search has been activated

This will by default show you a search form:

.. figure:: ../../_images/listing_search_default.png

   Listing search form after listing search has been activated


Deactivate a Listing Search
---------------------------

You can disable the embedding of a listing search at any time.
When you deactivate the embedding, your configuration will not be removed.
So if you later decide to enable the embedding again, you don't have to start from the beginning.

To deactivate the **Listing Search**, open the **Actions**-menu and select **Deactivate Listing Search**:

.. figure:: ../../_images/listing_search_deactivate.png

   Deactivate a listing search

When the **Listing Search** was deactivated, you will see a status message:

.. figure:: ../../_images/listing_search_deactivate_done.png

   Confirmation that the listing search has been deactivated


Configuration Options
=====================

To configure the **Listing Search** click on the new link **Configure Listing Search**:

.. figure:: ../../_images/listing_search_configuration.png

   Configuration options for a listing search

Once all configuration options are entered click the **Save** button.
